==> apache-brooklyn-1.0.0-src.zip: apache-brooklyn-1.0.0-src/brooklyn-server/camp/camp-brooklyn/src/test/java/org/apache/brooklyn/camp/brooklyn/ReferencedYamlOsgiTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.camp.brooklyn;

import org.apache.brooklyn.util.osgi.VersionedName;
import org.testng.annotations.Test;

/** like superclass, but with OSGi enabled, complex references now work */
public class ReferencedYamlOsgiTest extends ReferencedYamlTest {

    @Override
    protected boolean disableOsgi() {
        return false;
    }
    
    @Override
    protected void addCatalogItems(String catalogYaml) {
        addCatalogItemsAsOsgiWithoutStartingBundles(mgmt(), catalogYaml, VersionedName.fromString("sample-bundle:0-SNAPSHOT"), isForceUpdate());
    }
    
    // these are not broken with OSGi
    
    @Test
    public void testYamlReferencingEarlierItemLongFormEntity() throws Exception {
        super.testYamlReferencingEarlierItemLongFormEntity();
    }

    @Test
    public void testYamlReferencingEarlierItemInUrl() throws Exception {
        super.testYamlReferencingEarlierItemInUrl();
    }
    
    @Test
    public void testYamlReferencingEarlierItemInUrlAsType() throws Exception {
        super.testYamlReferencingEarlierItemInUrlAsType();
    }
    
}

==> apache-brooklyn-1.1.0-src.zip: apache-brooklyn-1.1.0-src/brooklyn-server/camp/camp-brooklyn/src/test/java/org/apache/brooklyn/camp/brooklyn/ReferencedYamlOsgiTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.camp.brooklyn;

import org.apache.brooklyn.api.typereg.RegisteredType;
import org.apache.brooklyn.util.osgi.VersionedName;
import org.testng.annotations.Test;

import java.util.Collection;

/** like superclass, but with OSGi enabled, complex references now work */
public class ReferencedYamlOsgiTest extends ReferencedYamlTest {

    @Override
    protected boolean disableOsgi() {
        return false;
    }
    
    @Override
    protected Collection<RegisteredType> addCatalogItems(String catalogYaml) {
        addCatalogItemsAsOsgiWithoutStartingBundles(mgmt(), catalogYaml, VersionedName.fromString("sample-bundle:0-SNAPSHOT"), isForceUpdate());
        return null;
    }
    
    // these are not broken with OSGi
    
    @Test
    public void testYamlReferencingEarlierItemLongFormEntity() throws Exception {
        super.testYamlReferencingEarlierItemLongFormEntity();
    }

    @Test
    public void testYamlReferencingEarlierItemInUrl() throws Exception {
        super.testYamlReferencingEarlierItemInUrl();
    }
    
    @Test
    public void testYamlReferencingEarlierItemInUrlAsType() throws Exception {
        super.testYamlReferencingEarlierItemInUrlAsType();
    }
    
}
